@@ -3,6 +3,7 @@ package SWF::Builder::Bitmap::Lossless::ImageMagick;
 use strict;
 
 our @ISA = ('SWF::Builder::Bitmap::Lossless');
+our $VERSION = '0.011';
 
 sub new {
     my ($class, $image) = @_;
@@ -16,7 +17,6 @@ sub new {
 	    my ($x, $y) = @_;
 	    my  @rgba = map{$_ & 255} split /,/, $image->Get("pixel[$x,$y]");
 	    $rgba[3] = 255-$rgba[3];
-	    return (0, 0, 0, 0) unless $rgba[3];
 	    return @rgba;
 	},
     }, $class;
